@@ -23,7 +23,7 @@ class Ui_MainWindow(object):
         self.switchOrder = False
         self.save = None
         self.tha = None
-        self.loading_widget=None
+        self.loading_widget = None
         MainWindow.setWindowTitle("SimplEdit")
         MainWindow.resize(1200, 850)
         sizePolicy = QtWidgets.QSizePolicy(
@@ -73,14 +73,14 @@ class Ui_MainWindow(object):
         self.tab_blending = QtWidgets.QWidget()
         self.tab_custom = QtWidgets.QWidget()
 
-        self.tabWidget.addTab(self.tab_home,     "Home")
-        self.tabWidget.addTab(self.tab_edit,     "Edit")
-        self.tabWidget.addTab(self.tab_color,    "Color")
-        self.tabWidget.addTab(self.tab_effects,  "Effects")
-        self.tabWidget.addTab(self.tab_filters,  "Filters")
+        self.tabWidget.addTab(self.tab_home, "Home")
+        self.tabWidget.addTab(self.tab_edit, "Edit")
+        self.tabWidget.addTab(self.tab_color, "Color")
+        self.tabWidget.addTab(self.tab_effects, "Effects")
+        self.tabWidget.addTab(self.tab_filters, "Filters")
         self.tabWidget.addTab(self.tab_creative, "Creative")
         self.tabWidget.addTab(self.tab_blending, "Blending")
-        self.tabWidget.addTab(self.tab_custom,   "Custom Effects")
+        self.tabWidget.addTab(self.tab_custom, "Custom Effects")
 
         self.tabWidget.setCurrentIndex(0)
 
@@ -270,20 +270,20 @@ class Ui_MainWindow(object):
         self.scrollArea.setWidgetResizable(True)
         self.scrollAreaWidgetContents = QtWidgets.QWidget()
         self.scrollArea.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
-        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 1200, 50))
+        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 1200, 75))
         self.horizontalLayout2 = QtWidgets.QHBoxLayout(self.scrollAreaWidgetContents)
         self.horizontalLayout2.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
         self.horizontalLayout2.setSpacing(5)
         self.tab_button(self, self.scrollAreaWidgetContents, (0, 0, 40, 40), "Add Custom Filter", "Add Filter")
         self.button.setIcon(QtGui.QIcon(self.location + "/images/add_filter.svg"))
         self.button.clicked.connect(self.add_custom)
-        self.button.setIconSize(QtCore.QSize(30, 30))
+        self.button.setIconSize(QtCore.QSize(40, 40))
         self.button.setMaximumSize(40, 40)
         self.horizontalLayout2.addWidget(self.button, 0, QtCore.Qt.AlignLeft)
-        self.tab_button(self, self.scrollAreaWidgetContents, (45, 0, 30, 30), "Remove Custom Filter", "Remove Filter")
+        self.tab_button(self, self.scrollAreaWidgetContents, (45, 0, 40, 40), "Remove Custom Filter", "Remove Filter")
         self.button.setIcon(QtGui.QIcon(self.location + "/images/remove.svg"))
         self.button.clicked.connect(self.remove_custom_filter)
-        self.button.setIconSize(QtCore.QSize(30, 30))
+        self.button.setIconSize(QtCore.QSize(40, 40))
         self.button.setMaximumSize(40, 40)
         self.horizontalLayout2.addWidget(self.button, 0, QtCore.Qt.AlignLeft)
         if not os.path.exists('test.txt'):
@@ -309,33 +309,33 @@ class Ui_MainWindow(object):
                     self.horizontalLayout2.addWidget(self.button)
                     self.horizontalLayout2.addWidget(self.button, 0, QtCore.Qt.AlignLeft)
         f.close()
-
         self.scrollArea.setWidget(self.scrollAreaWidgetContents)
         self.tabWidget.addTab(self.tab_custom, "Custom Filters")
-        if (self.currentCustom + 45 >= 1173):
-            self.scrollArea.setGeometry(QtCore.QRect(0, 0, 1173, 50))
+        if (self.currentCustom + 45 >= 1174):
+            self.scrollArea.setGeometry(QtCore.QRect(0, 0, 1174, 50))
         else:
-            self.scrollArea.setGeometry(QtCore.QRect(0, 0, self.currentCustom + 47, 50))
-        self.horizontalLayout2.setContentsMargins(0, 0, 7, 0)
+            self.scrollArea.setGeometry(QtCore.QRect(0, 0, self.currentCustom + 53, 50))
+        self.horizontalLayout2.setContentsMargins(1, 3, 7, 0)
 
         # Button Separators
 
-        self.tab_frame(self, self.tab_home,     (90,  0, 3, 61))
-        self.tab_frame(self, self.tab_edit,     (90,  0, 3, 61))
-        self.tab_frame(self, self.tab_edit,     (275, 0, 3, 61))
-        self.tab_frame(self, self.tab_color,    (180, 0, 3, 61))
-        self.tab_frame(self, self.tab_color,    (230, 0, 3, 61))
-        self.tab_frame(self, self.tab_effects,  (135, 0, 3, 61))
-        self.tab_frame(self, self.tab_effects,  (230, 0, 3, 61))
-        self.tab_frame(self, self.tab_filters,  (135, 0, 3, 61))
-        self.tab_frame(self, self.tab_filters,  (320, 0, 3, 61))
-        self.tab_frame(self, self.tab_creative, (45,  0, 3, 61))
-        self.tab_frame(self, self.tab_custom,   (self.currentCustom + 45, 0, 3, 61))
+        self.tab_frame(self, self.tab_home, (90, 0, 3, 61))
+        self.tab_frame(self, self.tab_edit, (90, 0, 3, 61))
+        self.tab_frame(self, self.tab_edit, (275, 0, 3, 61))
+        self.tab_frame(self, self.tab_color, (180, 0, 3, 61))
+        self.tab_frame(self, self.tab_color, (230, 0, 3, 61))
+        self.tab_frame(self, self.tab_effects, (135, 0, 3, 61))
+        self.tab_frame(self, self.tab_effects, (230, 0, 3, 61))
+        self.tab_frame(self, self.tab_filters, (135, 0, 3, 61))
+        self.tab_frame(self, self.tab_filters, (320, 0, 3, 61))
+        self.tab_frame(self, self.tab_creative, (45, 0, 3, 61))
+        self.tab_frame(self, self.tab_blending, (45, 0, 3, 61))
+        self.tab_frame(self, self.tab_custom, (self.currentCustom + 45, 0, 1, 61))
 
     def tab_button(self, MainWindow, widget_parent, position, status_tip, tool_tip):
         x, y, z, k = position
         self.button = QtWidgets.QToolButton(widget_parent)
-        self.button.setGeometry(QtCore.QRect(x, y+3, z, k))
+        self.button.setGeometry(QtCore.QRect(x, y + 3, z, k))
         if len(status_tip) > 0 and status_tip[len(status_tip) - 1: len(status_tip)] == '\n':
             status_tip = status_tip[0:len(status_tip) - 1]
         if len(tool_tip) > 0 and tool_tip[len(tool_tip) - 1: len(tool_tip)] == '\n':
@@ -359,6 +359,8 @@ class Ui_MainWindow(object):
         self.gridLayout.addWidget(self.tabWidget, 0, 0, 1, 1)
 
     def open_img(self, secondImage):
+        if self.switchOrder:
+            self.reorder_rescale()
         try:
             filename = QtWidgets.QFileDialog.getOpenFileName()
             imagePath = filename[0]
@@ -470,14 +472,14 @@ class Ui_MainWindow(object):
         self.tab_button(self, self.scrollAreaWidgetContents, (0, 0, 40, 40), "Add Custom Filter", "Add Filter")
         self.button.clicked.connect(self.add_custom)
         self.button.setIcon(QtGui.QIcon(self.location + "/images/add_filter.svg"))
-        self.button.setIconSize(QtCore.QSize(30, 30))
+        self.button.setIconSize(QtCore.QSize(40,40))
         self.button.setMaximumSize(40, 40)
         for i in reversed(range(self.horizontalLayout2.count())):
             self.horizontalLayout2.itemAt(i).widget().setParent(None)
         self.horizontalLayout2.addWidget(self.button, 0, QtCore.Qt.AlignLeft)
-        self.tab_button(self, self.scrollAreaWidgetContents, (45, 0, 30, 30), "Remove Custom Filter", "Remove Filter")
+        self.tab_button(self, self.scrollAreaWidgetContents, (45, 0, 40, 40), "Remove Custom Filter", "Remove Filter")
         self.button.clicked.connect(self.remove_custom_filter)
-        self.button.setIconSize(QtCore.QSize(30, 30))
+        self.button.setIconSize(QtCore.QSize(40, 40))
         self.button.setIcon(QtGui.QIcon(self.location + "/images/remove.svg"))
         self.button.setMaximumSize(40, 40)
         self.horizontalLayout2.addWidget(self.button, 0, QtCore.Qt.AlignLeft)
@@ -504,15 +506,15 @@ class Ui_MainWindow(object):
 
         self.scrollArea.setWidget(self.scrollAreaWidgetContents)
         self.tabWidget.addTab(self.tab_custom, "Custom Filters")
-        if (self.currentCustom + 45 >= 1173):
-            self.scrollArea.setGeometry(QtCore.QRect(0, 0, 1173, 50))
+        if (self.currentCustom + 45 >= 1174):
+            self.scrollArea.setGeometry(QtCore.QRect(0, 0, 1174, 50))
         else:
-            self.scrollArea.setGeometry(QtCore.QRect(0, 0, self.currentCustom + 47, 50))
-        self.horizontalLayout2.setContentsMargins(0, 0, 7, 0)
+            self.scrollArea.setGeometry(QtCore.QRect(0, 0, self.currentCustom + 53, 50))
+        self.horizontalLayout2.setContentsMargins(1, 3, 7, 0)
         self.lister = ''
         self.tabWidget.setCurrentIndex(7)
         self.m.setParent(None)
-        self.tab_frame(self, self.tab_custom, (self.currentCustom + 45, 0, 3, 61))
+        self.tab_frame(self, self.tab_custom, (self.currentCustom + 45, 0, 1, 61))
 
         # need to check if this is in the test.txt file and if it is, then remove it from that file, remove the txt file with name str.txt and move all the other filters down a place
 
@@ -648,10 +650,10 @@ class Ui_MainWindow(object):
         self.bri5.clicked.connect(
             lambda: self.add_filter('Border' + str(self.specialSlider5.value()) + str(self.color2)))
 
-        self.bri6=QtWidgets.QPushButton('Choose File To Blend')
-        self.hi=''
+        self.bri6 = QtWidgets.QPushButton('Choose File To Blend')
+        self.hi = ''
         self.bri6.clicked.connect(self.choose_file)
-        self.bri7=QtWidgets.QPushButton("Blend (Use Slider and File Selector Above Then Click)")
+        self.bri7 = QtWidgets.QPushButton("Blend (Use Slider and File Selector Above Then Click)")
         self.horizontalLayout.addWidget(self.bri6, 15, 0)
         self.specialSlider6 = QtWidgets.QSlider()
         self.specialSlider6.setValue(0)
@@ -662,9 +664,9 @@ class Ui_MainWindow(object):
         self.specialSlider6.setOrientation(QtCore.Qt.Horizontal)
         self.horizontalLayout.addWidget(self.specialSlider6, 15, 1)
         self.specialSlider6.setMaximumSize(400, 10)
-        self.horizontalLayout.addWidget(self.bri7, 16, 0, 1,2)
-        self.bri7.clicked.connect(lambda:self.add_filter('Blend'+str(self.hi)+' '+str(self.specialSlider6.value())))
-
+        self.horizontalLayout.addWidget(self.bri7, 16, 0, 1, 2)
+        self.bri7.clicked.connect(
+            lambda: self.add_filter('Blend' + str(self.hi) + ' ' + str(self.specialSlider6.value())))
 
         self.nameCustomTextBox = QtWidgets.QLineEdit('customName')
         self.sflip = QtWidgets.QPushButton('Flip')
@@ -680,10 +682,8 @@ class Ui_MainWindow(object):
             self.lister += '\n'
         self.lister += type
 
-
-
     def choose_file(self):
-        self.hi=QtWidgets.QFileDialog.getOpenFileName()[0]
+        self.hi = QtWidgets.QFileDialog.getOpenFileName()[0]
 
     def submit_name(self, name):
         if name == "" or name == 'test' or name == 'test\n':
@@ -746,16 +746,16 @@ class Ui_MainWindow(object):
             self.currentCustom = 45
             self.tab_button(self, self.scrollAreaWidgetContents, (0, 2, 40, 40), "Add Custom111 Filter", "Add Filter")
             self.button.clicked.connect(self.add_custom)
-            self.button.setIconSize(QtCore.QSize(30, 30))
+            self.button.setIconSize(QtCore.QSize(40, 40))
             self.button.setMaximumSize(40, 40)
             self.button.setIcon(QtGui.QIcon(self.location + "/images/add_filter.svg"))
             for i in reversed(range(self.horizontalLayout2.count())):
                 self.horizontalLayout2.itemAt(i).widget().setParent(None)
             self.horizontalLayout2.addWidget(self.button, 0, QtCore.Qt.AlignLeft)
-            self.tab_button(self, self.scrollAreaWidgetContents, (45, 0, 30, 30), "Remove Custom Filter",
+            self.tab_button(self, self.scrollAreaWidgetContents, (45, 0, 40, 40), "Remove Custom Filter",
                             "Remove Filter")
             self.button.clicked.connect(self.remove_custom_filter)
-            self.button.setIconSize(QtCore.QSize(30, 30))
+            self.button.setIconSize(QtCore.QSize(40, 40))
             self.button.setIcon(QtGui.QIcon(self.location + "/images/remove.svg"))
             self.button.setMaximumSize(40, 40)
             self.horizontalLayout2.addWidget(self.button, 0, QtCore.Qt.AlignLeft)
@@ -791,15 +791,15 @@ class Ui_MainWindow(object):
 
         self.scrollArea.setWidget(self.scrollAreaWidgetContents)
         self.tabWidget.addTab(self.tab_custom, "Custom Filters")
-        if (self.currentCustom + 45 >= 1173):
-            self.scrollArea.setGeometry(QtCore.QRect(0, 0, 1173, 50))
+        if (self.currentCustom + 45 >= 1174):
+            self.scrollArea.setGeometry(QtCore.QRect(0, 0, 1174, 50))
         else:
-            self.scrollArea.setGeometry(QtCore.QRect(0, 0, self.currentCustom + 47, 50))
-        self.horizontalLayout2.setContentsMargins(0, 0, 7, 0)
+            self.scrollArea.setGeometry(QtCore.QRect(0, 0, self.currentCustom + 53, 50))
+        self.horizontalLayout2.setContentsMargins(1, 3, 7, 0)
         self.lister = ''
 
         self.m.setParent(None)
-        self.tab_frame(self, self.tab_custom, (self.currentCustom + 45, 0, 3, 61))
+        self.tab_frame(self, self.tab_custom, (self.currentCustom + 45, 0, 1, 61))
         self.tabWidget.setCurrentIndex(7)
 
         _translate = QtCore.QCoreApplication.translate
@@ -811,8 +811,6 @@ class Ui_MainWindow(object):
                                                 "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:7.8pt; font-weight:400; font-style:normal;\">\n"
                                                 "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:10pt; color:#00007f;\">Here, you can create your own custom filters!  Just click on the filters you want to add in the order you want them and save your filter with a name (please only include alphanumeric characters or _ in name)!  When you\'re done, the filter will apply in your toolbar so you can apply it to any image!</span></p><br></br><br></br><p align = \"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:10pt; color:#23ce31;\">Filter added successfully!</body></html>"))
 
-
-
     def cleanup_ui(self):
         if self.image != None:
             if self.tha != None:
@@ -831,7 +829,7 @@ class Ui_MainWindow(object):
             else:
                 for i in reversed(range(self.horizontalLayout.count() - 1)):
                     self.horizontalLayout.itemAt(i + 1).widget().setParent(None)
-            if self.loading_widget!=None:
+            if self.loading_widget != None:
                 self.loading_widget.hide()
                 self.loading_widget.destroy()
 
@@ -843,8 +841,6 @@ class Ui_MainWindow(object):
                 img = self.image.get_current_image()
                 pixmap = ImageQt.toqpixmap(img)
                 self.labelWidget.setPixmap(pixmap.scaled(QtCore.QSize(600, 600), QtCore.Qt.KeepAspectRatio))
-            else:
-                print("cant undo, pos: " + str(self.image.get_index()) + " num images: " + str(self.image.num_images()))
 
     def redo(self):
         if self.image != None:
@@ -854,8 +850,6 @@ class Ui_MainWindow(object):
                 img = self.image.get_current_image()
                 pixmap = ImageQt.toqpixmap(img)
                 self.labelWidget.setPixmap(pixmap.scaled(QtCore.QSize(600, 600), QtCore.Qt.KeepAspectRatio))
-            else:
-                print("cant redo, pos: " + str(self.image.get_index()) + " num images: " + str(self.image.num_images()))
 
     def rotate_left(self):
         if self.image != None:
@@ -1224,141 +1218,143 @@ class Ui_MainWindow(object):
             pixmap = ImageQt.toqpixmap(m_img)
             self.labelWidget.setPixmap(pixmap.scaled(QtCore.QSize(600, 600), QtCore.Qt.KeepAspectRatio))
 
-
-
-
     def do_custom(self, name):
-            img = self.image.get_current_image()
-            f = open(name[0:len(name) - 1] + ".txt", "r")
-            for x in f:
-                if x[len(x) - 1:len(x)] == '\n':
-                    x = x[0:len(x) - 1]
-                if x == 'RotateL':
-                    img = im_functions.left_rotate(img)
-                elif x == 'RotateR':
-                    img = im_functions.right_rotate(img)
-                elif x == 'YellowT':
-                    img = im_functions.color_filter(img, 25, 25, 0)
-                elif x == 'RedT':
-                    img = im_functions.color_filter(img, 40, 10, 0)
-                elif x == 'Swirl':
-                    img = im_functions.swirl_effect(img)
-                elif x == 'Invert':
-                    img = im_functions.invert_filter(img)
-                elif x == 'GreenBlue':
-                    img = im_functions.color_filter(img, 0, 50, 25)
-                elif x == 'BlackWhite':
-                    img = im_functions.grayscale_filter(img)
-                elif x == 'Sepia':
-                    img = im_functions.sepia_filter(img)
-                elif x == 'ReduceNoise':
-                    img = im_functions.blur(img)
-                elif x == 'Enhance':
-                    img = im_functions.edge_enhance(img)
-                elif x == 'Smooth':
-                    img = im_functions.smooth(img)
-                elif x == 'Pixelate':
-                    img = im_functions.pixelate(img)
-                elif x == 'BlueYellow':
-                    img = im_functions.color_filter(img, 0, 25, 50)
-                elif x == 'Flip':
-                    img = im_functions.flip(img)
-                elif len(x) >= 8 and x[0:8] == 'Brighten':
-                    num = 0
-                    try:
-                        num = int(x[8:len(x)])
-                        if num > 200 or num < 0:
-                            continue
-                    except:
+        img = self.image.get_current_image()
+        f = open(name[0:len(name) - 1] + ".txt", "r")
+        for x in f:
+            if x[len(x) - 1:len(x)] == '\n':
+                x = x[0:len(x) - 1]
+            if x == 'RotateL':
+                img = im_functions.left_rotate(img)
+            elif x == 'RotateR':
+                img = im_functions.right_rotate(img)
+            elif x == 'YellowT':
+                img = im_functions.color_filter(img, 25, 25, 0)
+            elif x == 'RedT':
+                img = im_functions.color_filter(img, 40, 10, 0)
+            elif x == 'Swirl':
+                img = im_functions.swirl_effect(img)
+            elif x == 'Invert':
+                img = im_functions.invert_filter(img)
+            elif x == 'GreenBlue':
+                img = im_functions.color_filter(img, 0, 50, 25)
+            elif x == 'BlackWhite':
+                img = im_functions.grayscale_filter(img)
+            elif x == 'Sepia':
+                img = im_functions.sepia_filter(img)
+            elif x == 'ReduceNoise':
+                img = im_functions.blur(img)
+            elif x == 'Enhance':
+                img = im_functions.edge_enhance(img)
+            elif x == 'Smooth':
+                img = im_functions.smooth(img)
+            elif x == 'Pixelate':
+                img = im_functions.pixelate(img)
+            elif x == 'BlueYellow':
+                img = im_functions.color_filter(img, 0, 25, 50)
+            elif x == 'Flip':
+                img = im_functions.flip(img)
+            elif len(x) >= 8 and x[0:8] == 'Brighten':
+                num = 0
+                try:
+                    num = int(x[8:len(x)])
+                    if num > 200 or num < 0:
                         continue
-                    img = im_functions.adjust_brightness(img, num / 100)
+                except:
+                    continue
+                img = im_functions.adjust_brightness(img, num / 100)
 
-                elif len(x) >= 12 and x[0:12] == 'Transparency':
-                    num = 0
-                    try:
-                        num = int(x[12:len(x)])
-                        if num > 200 or num < 0:
-                            continue
-                    except:
+            elif len(x) >= 12 and x[0:12] == 'Transparency':
+                num = 0
+                try:
+                    num = int(x[12:len(x)])
+                    if num > 200 or num < 0:
                         continue
-                    img = im_functions.adjust_transparency(img, num / 100)
+                except:
+                    continue
+                img = im_functions.adjust_transparency(img, num / 100)
 
-                elif len(x) >= 8 and x[0:8] == 'Contrast':
-                    num = 0
-                    try:
-                        num = int(x[8:len(x)])
-                        if num > 200 or num < 0:
-                            continue
-                    except:
+            elif len(x) >= 8 and x[0:8] == 'Contrast':
+                num = 0
+                try:
+                    num = int(x[8:len(x)])
+                    if num > 200 or num < 0:
                         continue
-                    img = im_functions.adjust_contrast(img, num / 100)
+                except:
+                    continue
+                img = im_functions.adjust_contrast(img, num / 100)
 
-                elif len(x) >= 9 and x[0:9] == 'Intensity':
-                    num = 0
-                    try:
-                        num = int(x[9:len(x)])
-                        if num > 200 or num < 0:
-                            continue
-                    except:
+            elif len(x) >= 9 and x[0:9] == 'Intensity':
+                num = 0
+                try:
+                    num = int(x[9:len(x)])
+                    if num > 200 or num < 0:
                         continue
-                    img = im_functions.adjust_saturation(img, num / 100)
+                except:
+                    continue
+                img = im_functions.adjust_saturation(img, num / 100)
 
-                elif len(x)>=5 and x[0:5]=='Blend':
-                    num=0
+            elif len(x) >= 5 and x[0:5] == 'Blend':
+                num = 0
+                try:
+                    y = x[5:x.index(' ')]
+                    if not y.lower().endswith(('.png', '.jpg', '.jpeg', '.tiff', '.bmp', '.gif')):
+                        continue
+                    if not os.path.exists(y):
+                        continue
+                    im = ''
                     try:
-                        y=x[5:x.index(' ')]
-                        if not y.lower().endswith(('.png', '.jpg', '.jpeg', '.tiff', '.bmp', '.gif')):
-                            continue
-                        im = ''
                         im = Image.open(y).convert('RGBA')
-                        num=int(x[x.index(' ')+1:len(x)])
-                        img=im_functions.blend(img, im, num/100)
-                    except:
-                        return
-
-                elif len(x) >= 6 and x[0:6] == 'Border':
-                    num = 0
-                    tu = ''
-                    tickVal = ''
-                    try:
-                        end = x.index("(")
-                        num = int(x[6:end])
-                        x = x[end + 1:len(x)]
-                        p1 = x[0:x.index(',')]
-                        x = x[x.index(',') + 2:len(x)]
-                        p2 = x[0:x.index(',')]
-                        x = x[x.index(',') + 2:len(x)]
-                        p3 = ''
-                        try:
-                            p3 = x[0:x.index(',')]
-                        except:
-                            p3 = x[0:x.index(')')]
-
-                        p1 = int(p1)
-                        p2 = int(p2)
-                        p3 = int(p3)
-
-                        if num > 200 or num < 0 or p1 < 0 or p1 > 255 or p2 < 0 or p2 > 255 or p3 < 0 or p3 > 255:
-                            continue
-
-                        w, h = img.size
-                        minimum = min(w, h)
-                        tickVal = minimum / 200
-
                     except:
                         continue
-                    img = im_functions.create_border(img, tickVal * num, (p1, p2, p3))
+                    num = int(x[x.index(' ') + 1:len(x)])
+                    img = im_functions.blend(img, im, num / 100)
+                except:
+                    return
 
-            f.close()
-            self.image.increment_index()
-            index = self.image.get_index()
-            self.image.add_image(index, img)  # add modified image to object
-            pixmap = ImageQt.toqpixmap(img)  # converts PIL to pixmap
-            self.labelWidget.setPixmap(pixmap.scaled(QtCore.QSize(600, 600), QtCore.Qt.KeepAspectRatio))
-            self.horizontalLayout.itemAt(0).widget().setParent(None)
-            self.labelWidget.setPixmap(pixmap.scaled(QtCore.QSize(600, 600), QtCore.Qt.KeepAspectRatio))
-            self.horizontalLayout.addWidget(self.labelWidget, 0, 0)
-            self.loading_widget.hide()
+            elif len(x) >= 6 and x[0:6] == 'Border':
+                num = 0
+                tu = ''
+                tickVal = ''
+                try:
+                    end = x.index("(")
+                    num = int(x[6:end])
+                    x = x[end + 1:len(x)]
+                    p1 = x[0:x.index(',')]
+                    x = x[x.index(',') + 2:len(x)]
+                    p2 = x[0:x.index(',')]
+                    x = x[x.index(',') + 2:len(x)]
+                    p3 = ''
+                    try:
+                        p3 = x[0:x.index(',')]
+                    except:
+                        p3 = x[0:x.index(')')]
+
+                    p1 = int(p1)
+                    p2 = int(p2)
+                    p3 = int(p3)
+
+                    if num > 200 or num < 0 or p1 < 0 or p1 > 255 or p2 < 0 or p2 > 255 or p3 < 0 or p3 > 255:
+                        continue
+
+                    w, h = img.size
+                    minimum = min(w, h)
+                    tickVal = minimum / 200
+
+                except:
+                    continue
+                img = im_functions.create_border(img, tickVal * num, (p1, p2, p3))
+
+        f.close()
+        self.image.increment_index()
+        index = self.image.get_index()
+        self.image.add_image(index, img)  # add modified image to object
+        pixmap = ImageQt.toqpixmap(img)  # converts PIL to pixmap
+        self.labelWidget.setPixmap(pixmap.scaled(QtCore.QSize(600, 600), QtCore.Qt.KeepAspectRatio))
+        self.horizontalLayout.itemAt(0).widget().setParent(None)
+        self.labelWidget.setPixmap(pixmap.scaled(QtCore.QSize(600, 600), QtCore.Qt.KeepAspectRatio))
+        self.horizontalLayout.addWidget(self.labelWidget, 0, 0)
+        self.loading_widget.hide()
 
     def process_custom(self, name):
         if self.image != None:
@@ -1375,7 +1371,7 @@ class Ui_MainWindow(object):
             self.app.processEvents()
             self.loading_widget.show()
             self.loading_widget.update()
-            run = threading.Thread(target=lambda:self.do_custom(name))
+            run = threading.Thread(target=lambda: self.do_custom(name))
             run.start()
 
     def process_swirl(self):
@@ -1459,7 +1455,7 @@ class Ui_MainWindow(object):
             else:
                 for i in reversed(range(self.horizontalLayout.count() - 1)):
                     self.horizontalLayout.itemAt(i + 1).widget().setParent(None)
-            if self.loading_widget!=None:
+            if self.loading_widget != None:
                 self.loading_widget.hide()
                 self.loading_widget.destroy()
 
@@ -1562,7 +1558,7 @@ class Ui_MainWindow(object):
             self.horizontalLayout.addWidget(self.labelWidget2, 0, 0)
             self.horizontalLayout.addWidget(self.labelWidget, 0, 1)
             self.switchOrder = True
-        
+
         elif self.image != None and self.switchOrder == True:
             self.cleanup_ui()
 
@@ -1635,7 +1631,7 @@ class Ui_MainWindow(object):
                         ImageQt.toqpixmap(self.imagine).scaled(QtCore.QSize(600, 600), QtCore.Qt.KeepAspectRatio)))
                 self.horizontalLayout.addWidget(self.labelWidget3, 0, 1)
                 self.bu = QtWidgets.QPushButton("Apply")
-                self.horizontalLayout.addWidget(self.bu, 19, 1)
+                self.horizontalLayout.addWidget(self.bu, 19,2)
                 self.bu.clicked.connect(self.blend_save)
                 self.slider_widget = QtWidgets.QSlider()
                 self.slider_widget.setMinimum(0)
@@ -1643,7 +1639,8 @@ class Ui_MainWindow(object):
                 self.slider_widget.setTickInterval(5)
                 self.slider_widget.setSliderPosition(0)
                 self.slider_widget.setValue(0)
-                self.horizontalLayout.addWidget(self.slider_widget, 19, 0)
+                self.horizontalLayout.addWidget(self.slider_widget, 19, 0,1,2)
+                self.bu.setMaximumSize(95,40)
                 self.slider_widget.setOrientation(QtCore.Qt.Horizontal)
                 self.slider_widget.valueChanged.connect(self.blend)
         except:
